/*
 * @brief NTAG Originality Signature Validation example based on easy_ecc library.
 *
 * @note
 * Copyright(C) NXP Semiconductors, 2021
 * All rights reserved.
 *
 * @par
 * Software that is described herein is for illustrative purposes only
 * which provides customers with programming information regarding the
 * LPC products.  This software is supplied "AS IS" without any warranties of
 * any kind, and NXP Semiconductors and its licensor disclaim any and
 * all warranties, express or implied, including all implied warranties of
 * merchantability, fitness for a particular purpose and non-infringement of
 * intellectual property rights.  NXP Semiconductors assumes no responsibility
 * or liability for the use of the software, conveys no license or rights under any
 * patent, copyright, mask work right, or any other intellectual property rights in
 * or to any products. NXP Semiconductors reserves the right to make changes
 * in the software without notification. NXP Semiconductors also makes no
 * representation or warranty that such application will be suitable for the
 * specified use without further testing or modification.
 *
 * @par
 * Permission to use, copy, modify, and distribute this software and its
 * documentation is hereby granted, under NXP Semiconductors' and its
 * licensor's relevant copyrights in the software, without fee, provided that it
 * is used in conjunction with NXP Semiconductors microcontrollers.  This
 * copyright, permission, and disclaimer notice must appear in all copies of
 * this code.
 */

#include <stdio.h>
#include "ecc.h"

int main(void)
{
    int exit = 0;

    //OSG Authentication - PubKey from Application note AN11350
    uint8_t PubKey[] = { 0x04, 0x49, 0x4E, 0x1A, 0x38, 0x6D, 0x3D, 0x3C,
        0xFE, 0x3D, 0xC1, 0x0E, 0x5D, 0xE6, 0x8A, 0x49,
        0x9B, 0x1C, 0x20, 0x2D, 0xB5, 0xB1, 0x32, 0x39,
        0x3E, 0x89, 0xED, 0x19, 0xFE, 0x5B, 0xE8, 0xBC, 0x61 };

    //From AN11350
    uint8_t UIDLong[] = { 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x04, 0x21, 0x09, 0x89, 0x99, 0x94, 0x70 };

    uint8_t OSGLong[] = { 0xE1, 0x46, 0x1F, 0x2E, 0x50, 0x3D, 0x16, 0x3A,
        0x3F, 0x8F, 0xD1, 0x6B, 0xE6, 0x47, 0x9A, 0x4A,
        0x99, 0xCD, 0xED, 0xF6, 0x20, 0x8A, 0x15, 0x7A,
        0x76, 0x6E, 0xAD, 0x0B, 0x2E, 0x99, 0x95, 0xD7 };

    exit = ecdsa_verify(PubKey, UIDLong, OSGLong);
    if (exit){
        printf("ECC Originality Signature Verified Successfully.\n");
    }else{
        printf("ECC Originality Signature Verification Failed!\n");
    }
        
    return exit;
}
